Package 'survo.audio'

Title: Sound support for Survo R
Description: Provides sound-API for Survo R.
Authors: Reijo Sund <[email protected]>
Maintainer: Reijo Sund <[email protected]>
License: GPL-2
Version: 0.2.1
Built: 2026-05-27 09:46:37 UTC
Source: https://github.com/rsund/survor

Help Index


Play WAV sample

Description

Provides audio support and default samples for Survo R

Usage

survo.play(sound = "default", async = TRUE, timeout = NA)

Arguments

sound

Name of default sample or path for WAV-file.

async

Is sample played asynchronously (no wait) or synchronously (wait).

timeout

How long time in seconds the sample will be played, NA=play whole sample.

Details

Path to uncompressed .WAV file will play that file. There are also several samples included with the package in the data survo.sounds (survo.sounds and those can be used by giving just the name of the sample.

Value

There is no meaningful return value.

Author(s)

Reijo Sund

See Also

survo.tone, survo.sounds, ~~~

Examples

## Not run: 
survo.play(sound="GLASS",async=FALSE,timeout=2)
survo.play("APPLAUSE")

## End(Not run)

Sounds for Survo R

Description

Default samples for Survo R in audioSample format.

Usage

data(survo.sounds)

Format

The format is: List of 72 $ default $ APPLAUSE $ bilj $ biljs $ CAMERA $ CARBRAKE $ CASHREG $ CHIMES $ CHK_ERR $ CLAP $ Cuculus.canorus $ DRIVEBY $ DRUMROLL $ EXPLODE $ Fringilla.coelebs $ GLASS $ GUNSHOT $ kahdeks $ kaksi $ kmmenen $ kolme $ kuusi $ kymm $ KYMMENEN $ LASER $ miinus $ milj $ miljs $ milrd $ milrds $ nelja $ newalert $ nolla $ offspread $ pilkku $ plus $ PROJCTOR $ PROTECT $ RICOCHET $ ringout $ sata $ sataa $ seitsem $ SM1 $ SM2 $ SM3 $ SM4 $ SM5 $ SM6 $ SM7 $ SM8 $ SP1 $ SP2 $ SP3 $ SP4 $ SP5 $ SP6 $ SP7 $ SP8 $ SUR_ACT $ SUR_ML $ SUR_MR $ toista $ tuhat $ tuhatta $ TYPE $ TYPE2 $ viisi $ WHOOSH $ XXX1 $ yhdeks $ yksi

Details

Samples in audioSample format (.WAV-files loaded with load.wave()-function from the audio-package).

Samples from the Survo MM distribution.


Play pure tone

Description

Provides pure tone playing for Survo R

Usage

survo.tone(tonefreq=420, duration = 0.2, sampfreq=22050)

Arguments

tonefreq

Tone to play in Hz.

duration

Length of tone in seconds.

sampfreq

Sampling frequency to be used.

Details

Plays whole tone synchronously.

Value

There is no return value.

Author(s)

Reijo Sund

See Also

survo.play, ~~~

Examples

## Not run: 
survo.tone()
survo.tone(1500,2,44100)

## End(Not run)